#!/bin/bash

# shellcheck disable=SC1091

set -o errexit
set -o nounset
set -o pipefail
#set -o xtrace # Uncomment this line for debugging purpose

# Enable job control
# ref https://www.gnu.org/software/bash/manual/bash.html#The-Set-Builtin
set -m

# Load Redis environment variables
. /opt/scripts/redis-cluster-env.sh

# Load libraries
. /opt/scripts/libos.sh
. /opt/scripts/librediscluster.sh

read -ra nodes <<< "$(tr ',;' ' ' <<< "${REDIS_NODES}")"

ARGS=("--include" "${REDIS_BASE_DIR}/etc/redis.conf")

if ! is_boolean_yes "$ALLOW_EMPTY_PASSWORD"; then
ARGS+=("--requirepass" "$REDIS_PASSWORD")
ARGS+=("--masterauth" "$REDIS_PASSWORD")
#ARGS+=("--loglevel" "debug")
else
ARGS+=("--protected-mode" "no")
fi

if is_boolean_yes "$REDIS_TLS_ENABLED"; then
ARGS+=("--port" "0")
ARGS+=("--tls-port" "${REDIS_TLS_PORT_NUMBER}")
ARGS+=("--tls-cert-file" "${REDIS_TLS_CERT_FILE}")
ARGS+=("--tls-key-file" "${REDIS_TLS_KEY_FILE}")
ARGS+=("--tls-ca-cert-file" "${REDIS_TLS_CA_FILE}")
ARGS+=("--tls-auth-clients" "yes")
else
ARGS=("--port" "$REDIS_PORT_NUMBER")
fi

ARGS+=("$@")
info "....... Server is getting started ..."
echo "cluster creator ${REDIS_CLUSTER_CREATOR} ${REDIS_DATA_DIR} ${REDIS_NODES}"

if is_boolean_yes "$REDIS_CLUSTER_CREATOR" && ! [[ -f "${REDIS_DATA_DIR}/nodes.conf" ]]; then
    # Start Redis in background
    if am_i_root; then
        info "....... Server is running with ROOT ..."
        gosu "$REDIS_DAEMON_USER" redis-server "${ARGS[@]}" &
        info "server is started"
    else
        redis-server "${ARGS[@]}" &
    fi
    # Create the cluster
    redis_cluster_create "${nodes[@]}"
    info "cluster is created"
    # Bring redis process to foreground
    fg
else
    if am_i_root; then
        info "cluster already created, start with ROOT"
        exec gosu "$REDIS_DAEMON_USER" redis-server "${ARGS[@]}"
    else
        info "cluster already created"
        exec redis-server "${ARGS[@]}"
    fi
fi
